# To watch

## Anime

* https://myanimelist.net/anime/38000/Kimetsu_no_Yaiba?q=Daemon%20Slayer&cat=anime
* https://myanimelist.net/anime/41457/86?q=86&cat=anime

## Misc links from Bigorneau

* Films/Séries/Animes  -> https://trakt.tv/
* Livres -> https://www.goodreads.com/
* Mangas -> https://myanimelist.net/ avec https://tachiyomi.org/ (app Android)